;;; The registers defined on the 8051FA and 8052
T2CON  equ 0c8h
RCAP2L equ 0cah
RCAP2H equ 0cbh
TL2    equ 0cch
TH2    equ 0cdh

SADDR equ 0a9h
SADEN equ 0b9h

T2MOD equ 0c9h

CCON equ 0d8h
CMOD equ 0d9h
CCAPM0 equ 0dah
CCAPM1 equ 0dbh
CCAPM2 equ 0dch
CCAPM3 equ 0ddh
CCAPM4 equ 0deh
CL equ 0e9h
CH equ 0f9h
CCAP0L equ 0eah
CCAP0H equ 0fah
CCAP1L equ 0ebh
CCAP1H equ 0fbh
CCAP2L equ 0ech
CCAP2H equ 0fch
CCAP3L equ 0edh
CCAP3H equ 0fdh
CCAP4L equ 0eeh
CCAP4H equ 0feh

;;; Addressable bits
;;; Port 1 ... does NOT match with Intel's description.
T2   bit P1.0
T2EX bit P1.1
ECI  bit P1.2
CEX0 bit P1.3
CEX1 bit P1.4
CEX2 bit P1.5
CEX3 bit P1.6
CEX4 bit P1.7

;;; IE and IP
ET2 bit IE.5
EC  bit IE.6
PT2 bit IP.5
PPC bit IP.6

;;; T2CON
TF2    bit T2CON.7
EXF2   bit T2CON.6
RCLK   bit T2CON.5
TCLK   bit T2CON.4
EXEN2  bit T2CON.3
TR2    bit T2CON.2
C_T2   bit T2CON.1
CP_RL2 bit T2CON.0

;;; CCON
CF bit CCON.7
CR bit CCON.6
CCF4 bit CCON.4
CCF3 bit CCON.3
CCF2 bit CCON.2
CCF1 bit CCON.1
CCF0 bit CCON.0

;;; Non-addressible bits
;;; T2MOD
DCEN equ 00h

;;; CMOD
CIDL equ 80h
WDTE equ 40h
CPS1 equ  4
CPS0 equ  2
ECF  equ  1

;;; CCAPM*
;;; 16-bit capture mode    = x 0 * * 0 0 0 *
;;; 16-bit comparator mode = x * 0 0 * * 0 *
;;;  8-bit PWM mode        = x * 0 0 0 0 * 0
;;; Watchdog timer mode    = x * 0 0 1 x 0 x  Counter 4 only, WDTE set.
ECOM equ 40h
CAPP equ 20h
CAPN equ 10h
MAT  equ  8
TOG  equ  4
PWM  equ  2
ECCF equ  1

;;;Here's another include file for the 8051 family:
;;;From: Anders Plambech <plambech@panni3.mfi.ku.dk>
;;;
;; The program is a assembler code to a 80c652 chip, ther send data through a HIO
;;bus to a PCA8515 OSD chip from PHILIPS.
;;
;;                       Yours sincerely
;;                       Anders Plambech 
;
;___________________________EQU COMMAND BEGIN______________________________
;                                                                          |
CMD0            EQU 01111000B   ;select command bank                       |
CMD1            EQU 10000000B   ;display char (bank1)                      |
CMD2            EQU 00000000B   ;attribute                                 |
CMD3            EQU 00100000B   ;display char addr H                       |
CMD4            EQU 00110000B   ;display char addr L                       |
CMD5            EQU 00000000B   ;display char (bank2)                      |
CMD6            EQU 00000000B   ;OSD pll dividend                          |
CMD7            EQU 01000000B   ;control register 1                        |
CMD8            EQU 01010000B   ;control register 2                        |
CMD9            EQU 01100000B   ;control register 3                        |
CMDA            EQU 01110000B   ;control register 4                        |
CMDB            EQU 10010000B   ;vertical start position H                 |
CMDC            EQU 10100000B   ;vertical position L/horizontal position H |
CMDD            EQU 10110000B   ;horizontal start position L               |
CMDE            EQU 11000000B   ;port 0 value (write)                      |
CMDF            EQU 01000000B   ;bg color in frame shadowing mode          |
;                               ;control register 5                        |
;                                                                          |
CMDG            EQU 01010000B   ;                                          |
;                                                                          |
ALL0            EQU 0CFH        ;transparent pattern                       |
ALL1            EQU 018H        ;dark pattern                              |
;                                                                          |
BANK0           EQU 00000000B   ;BS1=0 BS0=0                               |
BANK1           EQU 00000001B   ;BS1=0 BS0=1                               |
BANK2           EQU 00000010B   ;BS1=1 BS0=0                               |
;                                                                          |
;SPACE & CHAR CONTROL                                                      |
;                                                                          |
DOS_SP          EQU 0FFH        ;SPACE                                     |
RED             EQU 00010000B   ;                                          |
GREEN           EQU 00001000B   ;                                          |
BLUE            EQU 00000100B   ;                                          |
INTY            EQU 00000010B   ;                                          |
ACM             EQU 00000001B   ;                                          |
BLINK           EQU 00000001B   ;                                          |
;                                                                          |
;CARRIAGE RETURN CONTROL                                                   |
;                                                                          |
DOS_CR          EQU 0FEH        ;CARRIAGE RETURN                           |
H1V1            EQU 00000000B   ;1 dot = 1H1V                              |
H2V2            EQU 00001000B   ;1 dot = 2H2V                              |
H3V3            EQU 00010000B   ;1 dot = 3H3V                              |
H4V4            EQU 00011000B   ;1 dot = 4H4V                              |
LINE0           EQU 00000000B   ;0  H line spacing                         |
LINE4           EQU 00000010B   ;4  H line spacing                         |
LINE8           EQU 00000100B   ;8  H line spacing                         |
LINE12          EQU 00000110B   ;12 H line spacing                         |
EOD             EQU 00000001B   ;END OF DISPLAY                            |
;                                                                          |
;CONTROL REGISTER 1                                                        |
;                                                                          |
LPF525_60HZ_NTSC  EQU 00000000B ;M1=0, M0=0; 1V 1H                         |
LPF625_50HZ_PAL   EQU 00000000B ;M1=0, M0=0  1V 1H                         |
LPF1050_60HZ_NTSC EQU 00001000B ;M1=1, M0=0  1V 2H                         |
LPF1250_100HZ_PAL EQU 00001100B ;M1=1, M0=1  2V 2H                         |
BP_H            EQU 00000010B   ;FB, ACM ,RGB ACTIVE HIGH                  |
BP_L            EQU 00000000B   ;FB, ACM ,RGB ACTIVE LOW                   |
OSD_E           EQU 00000001B   ;OSD ENABLE                                |
;                                                                          |
;CONTROL REGISTER 2                                                        |
;                                                                          |
HP_H            EQU 00001000B   ;HSYNC INPUT POLARITY HIGH                 |
HP_L            EQU 00000000B   ;HSYNC INPUT POLARITY LOW                  |
VP_H            EQU 00000100B   ;VSYNC INPUT POLARITY HIGH                 |
VP_L            EQU 00000000B   ;VSYNC INPUT POLARITY LOW                  |
SUPER           EQU 00000000B   ;SUPERIMPOSE MODE, S1=0 S0=0               |
NORTH_WEST      EQU 00000001B   ;NORTH WEST  MODE, S1=0 S0=1               |
BOX             EQU 00000010B   ;BOX SHADOW  MODE, S1=1 S0=0               |
FRAME           EQU 00000011B   ;FRAME       MODE, S1=1 S0=1               |
;                                                                          |
;CONTROL REGISTER 3 (COMMAND 9)                                            |
;                                                                          |
VSYN_16         EQU 00000000B   ;BLINK FREQUENCY = Vsyn/16 Hz              |
VSYN_32         EQU 00000100B   ;BLINK FREQUENCY = Vsyn/32 Hz              |
VSYN_64         EQU 00001000B   ;BLINK FREQUENCY = Vsyn/64 Hz              |
VSYN_128        EQU 00001100B   ;BLINK FREQUENCY = Vsyn/128 Hz             |
AR3_1           EQU 00000000B   ;ACTIVE RATIO 3:1                          |
AR1_1           EQU 00000001B   ;ACTIVE RATIO 1:1                          |
AR1_3           EQU 00000010B   ;ACTIVE RATIO 1:3                          |
;                                                                          |
;CONTROL REGISTER 4                                                        |
;                                                                          |
AP0             EQU 00000000B   ;A/P=P04                                   |
AP1             EQU 00000100B   ;A/P=ACM                                   |
PI0             EQU 00000000B   ;PINS 17, 19, 21, 23 works as general port |
PI1             EQU 00000001B   ;PINS 17, 19, 21, 23 works as              |
                                ; RI, GI, BI, FBI                          |
;                                                                          |
;                                                                          |
;DEFINE HIO CONTROL LINE                                                   |
;                                                                          |
        SCLK        EQU   P1.6            ;HIO clock                       |
        SIN         EQU   P1.7            ;HIO data                        |
        HIOE        EQU   P1.5            ;HIO enable                      |
;                                                                          |
;                                                                          |
;___________________________EQU COMMANDS END_______________________________|
