//am29200.h
//memory mapped registers for the AMD AM29200 processor
//displacements relative to 0x80000000
//to be used as index in array
//19930609/wjvg

#define DMEM_RMCT  0x00  //ROM control register
#define DMEM_RMCF  0x04  //ROM configuration register
#define DMEM_DRCT  0x08  //DRAM control register
#define DMEM_DRCF  0x0c  //DRAM configuration register

#define DMEM_DRM0  0x10  //DRAM mapping register 0
#define DMEM_DRM1  0x14  //DRAM mapping register 1
#define DMEM_DRM2  0x18  //DRAM mapping register 2
#define DMEM_DRM3  0x1c  //DRAM mapping register 3

#define DMEM_PICT0 0x20  //PIA control register 0
#define DMEM_PICT1 0x24  //PIA control register 1
#define DMEM_ICT   0x28  //interrupt control register

#define DMEM_DMCT0 0x30  //DMA0 control register
#define DMEM_DMAD0 0x34  //DMA0 address register
#define DMEM_TAD0  0x36  //DMA0 address tail register
#define DMEM_DMCN0 0x38  //DMA0 count register
#define DMEM_TCN0  0x3a  //DMA0 count tail register

#define DMEM_DMCT1 0x40  //DMA1 control register
#define DMEM_DMAD1 0x44  //DMA1 address register
#define DMEM_TAD1  0x46  //DMA1 address tail register
#define DMEM_DMCN1 0x48  //DMA1 count register
#define DMEM_TCN1  0x4a  //DMA1 count tail register

#define DMEM_SPCT  0x80  //serial port control register
#define DMEM_SPST  0x84  //serial port status register
#define DMEM_SPTH  0x88  //serial port transmit holding register
#define DMEM_SPRB  0x8c  //serial port receive buffer register

#define DMEM_BAUD  0x90  //baud rate divisor register
#define DMEM_PPCT  0xc0  //parallel port control register
#define DMEM_PPST  0xc1  //parallel port status register
#define DMEM_PPDT  0xc4  //parallel port data register

#define DMEM_POCT  0xd0  //PIO control register
#define DMEM_PIN   0xd4  //PIO input register
#define DMEM_POUT  0xd8  //PIO output register
#define DMEM_POEN  0xdc  //PIO output enable register

#define DMEM_VCT   0xe0  //video control register
#define DMEM_TOP   0xe4  //video margin register
#define DMEM_SIDE  0xe8  //side margin register
#define DMEM_VDT   0xec  //video data holding register

#define ICT_TXDI   (   1<< 5)  //transmit data interrupt
#define ICT_RXDI   (   1<< 6)  //receive data interrupt
#define ICT_RXSI   (   1<< 7)  //receive status interrupt
#define ICT_PPI    (   1<<11)  //parallel port interrupt
#define ICT_DMA1I  (   1<<13)  //dma channel 1 interrupt
#define ICT_DMA0I  (   1<<14)  //dma channel 0 interrupt
#define ICT_F_IOPI (   1<<16)  //faktor van io port interrupt bits
#define ICT_M_IOPI (0xff<<16)  //masker van io port interrupt bits
#define ICT_VDI    (   1<<27)  //video interrupt

#define SPCT_LOOP    (1<<26)  //loopback
#define SPCT_BRK     (1<<25)  //send break
#define SPCT_DSR     (1<<24)  //data set ready
#define SPCT_PARNO   (0<<19)  //no parity
#define SPCT_PARODD  (4<<19)  //odd parity
#define SPCT_PAREVEN (5<<19)  //even parity
#define SPCT_PAR1    (6<<19)  //parity always 1
#define SPCT_PAR0    (7<<19)  //parity always 0
#define SPCT_STP     (1<<18)  //stop bits-1
#define SPCT_F_BITS  (1<<16)  //faktor for word length
#define SPCT_M_BITS  (3<<16)  //masker for word length
#define SPCT_5BITS   (0<<16)  //5 bits
#define SPCT_6BITS   (1<<16)  //6 bits
#define SPCT_7BITS   (2<<16)  //7 bits
#define SPCT_8BITS   (3<<16)  //8 bits
#define SPCT_F_TMODE (1<< 8)  //faktor for transmit mode
#define SPCT_M_TMODE (3<< 8)  //masker for transmit mode
#define SPCT_TIDIS   (0<< 8)  //transmit interrupts disabled
#define SPCT_TIEN    (1<< 8)  //transmit interrupts enabled
#define SPCT_TIDMA0  (2<< 8)  //transmit interrupts via dma0
#define SPCT_TIDMA1  (3<< 8)  //transmit interrupts via dma1
#define SPCT_RSIE    (1<< 2)  //receive status interrupt enable
#define SPCT_F_RMODE (1<< 0)  //faktor for receive mode
#define SPCT_M_RMODE (3<< 0)  //masker for receive mode
#define SPCT_RIDIS   (0<< 0)  //receive interrupts disabled
#define SPCT_RIEN    (1<< 0)  //receive interrupts enabled
#define SPCT_RIDMA0  (2<< 0)  //receive interrupts via dma0
#define SPCT_RIDMA1  (3<< 0)  //receive interrupts via dma1

#define SPST_TEMT (1<<10)  //transmitter empty
#define SPST_THRE (1<< 9)  //transmit holding register empty
#define SPST_RDR  (1<< 8)  //receive data ready
#define SPST_DTR  (1<< 4)  //data terminal ready
#define SPST_BRKI (1<< 3)  //break interrupt
#define SPST_FER  (1<< 2)  //framing error
#define SPST_PER  (1<< 1)  //parity error
#define SPST_OER  (1<< 0)  //overrun error

#define baud2div(n) (32000000/32/(n)-1)  //baudrate to divisor
#define BAUD_9600   baud2div(9600)       //baudrate-factor for 9600 baud

//end
