// ========================================================================
//
// ucb1200.h
//
// Definitions for the chip-specific I/O registers on the UCB1200.
//
//
// Copyright (c) 2000 Denis Hennessy, Ground Zero Development
// <denis@g0dev.com>
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2 of the License, or (at your
// option) any later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
// or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
// for more details.
// 
// You should have received a copy of the GNU General Public License along
// with this program; if not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
// ========================================================================

#ifndef  UCB1200_H
#define  UCB1200_H

#include <basetype.h>

// Register 0: I/O port data register

union BtyIOData {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
          u16 io_data : 10;
          u16 reserved : 6;
#else
          u16 reserved : 6;
          u16 io_data : 10;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 1: I/O port direction register

union BtyIODir {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
          u16 io_dir : 10;
          u16 reserved : 5;
          u16 sib_zero : 1;
#else
          u16 sib_zero : 1;
          u16 reserved : 5;
          u16 io_data : 10;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 2: Rising edge interrupt enable register

union BtyREIEn {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
          u16 io_ris_int : 10;
          u16 adc_ris_int : 1;
          u16 tspx_ris_int : 1;
          u16 tsmx_ris_int : 1;
          u16 tclip_ris_int : 1;
          u16 aclip_ris_int : 1;
#else
          u16 aclip_ris_int : 1;
          u16 tclip_ris_int : 1
          u16 tsmx_ris_int : 1;
          u16 tspx_ris_int : 1;
          u16 adc_ris_int : 1;
          u16 io_ris_int : 10;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 3: Falling edge interrupt enable register

union BtyFEIEn {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
          u16 io_fal_int : 10;
          u16 adc_fal_int : 1;
          u16 tspx_fal_int : 1;
          u16 tsmx_fal_int : 1;
          u16 tclip_fal_int : 1;
          u16 aclip_fal_int : 1;
#else
          u16 aclip_fal_int : 1;
          u16 tclip_fal_int : 1
          u16 tsmx_fal_int : 1;
          u16 tspx_fal_int : 1;
          u16 adc_fal_int : 1;
          u16 io_fal_int : 10;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 4: Interrupt clear/status register

union BtyInt {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
          u16 io_int : 10;
          u16 adc_int : 1;
          u16 tspx_int : 1;
          u16 tsmx_int : 1;
          u16 tclip_int : 1;
          u16 aclip_int : 1;
#else
          u16 aclip_int : 1;
          u16 tclip_int : 1
          u16 tsmx_int : 1;
          u16 tspx_int : 1;
          u16 adc_int : 1;
          u16 io_int : 10;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 5: Telecom control register A

union BtyTelCRA {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
          u16 tel_div : 7;
          u16 tel_loop : 1;
          u16 reserved : 8;
#else
          u16 reserved : 8;
          u16 tel_loop : 1;
          u16 tel_div : 7;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 6: Telecom control register B

union BtyTelCRB {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
         u16 reserved0 : 3;
         u16 tel_voice_ena : 1;
         u16 tel_clip : 1;
         u16 reserved5 : 1;
         u16 tel_att : 1;
         u16 reserved7 : 4;
         u16 tel_side_ena : 1;
         u16 reserved12 : 1;
         u16 tel_mute : 1;
         u16 tel_in_ena : 1;
         u16 tel_out_ena : 1;
#else
         u16 tel_out_ena : 1;
         u16 tel_in_ena : 1;
         u16 tel_mute : 1;
         u16 reserved12 : 1;
         u16 tel_side_ena : 1;
         u16 reserved7 : 4;
         u16 tel_att : 1;
         u16 reserved5 : 1;
         u16 tel_clip : 1;
         u16 tel_voice_ena : 1;
         u16 reserved0 : 3;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 7: Audio control register A

union BtyAudCRA {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
          u16 aud_div : 7;
          u16 aud_gain : 5;
          u16 reserved : 4;
#else
          u16 reserved : 4;
          u16 aud_gain : 5;
          u16 aud_div : 7;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 8: Audio control register B

union BtyAudCRB {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
         u16 aud_att : 5;
         u16 reserved5 : 1;
         u16 aud_clip : 1;
         u16 reserved7 : 1;
         u16 aud_loop : 1;
         u16 reserved9 : 4;
         u16 aud_mute : 1;
         u16 aud_in_ena : 1;
         u16 aud_out_ena : 1;
#else
         u16 aud_out_ena : 1;
         u16 aud_in_ena : 1;
         u16 aud_mute : 1;
         u16 reserved9 : 4;
         u16 aud_loop : 1;
         u16 reserved7 : 1;
         u16 aud_clip : 1;
         u16 reserved5 : 1;
         u16 aud_att : 5;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 9: Touch screen control register

union BtyTSCR {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
         u16 tsmx_pow : 1;
         u16 tspx_pow : 1;
         u16 tsmy_pow : 1;
         u16 tspy_pow : 1;
         u16 tsmx_gnd : 1;
         u16 tspx_gnd : 1;
         u16 tsmy_gnd : 1;
         u16 tspy_gnd : 1;
         u16 tsc_mode : 2;
         u16 reserved10 : 1;
         u16 tsc_bias_ena : 1;
         u16 tspx_low : 1;
         u16 tsmx_low : 1;
         u16 reserved14 : 2;
#else
         u16 reserved14 : 2;
         u16 tspx_low : 1;
         u16 tsc_bias_ena : 1;
         u16 reserved10 : 1;
         u16 tsc_mode : 2;
         u16 tspy_gnd : 1;
         u16 tsmy_gnd : 1;
         u16 tspx_gnd : 1;
         u16 tsmx_gnd : 1;
         u16 tspy_pow : 1;
         u16 tsmy_pow : 1;
         u16 tspx_pow : 1;
         u16 tsmx_pow : 1;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 10: ADC control register

union BtyADCCR {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
         u16 adc_sync_ena : 1;
         u16 vrefbyp_con : 1;
         u16 adc_input : 3;
         u16 ext_ref_ena : 1;
         u16 reserved6 : 1;
         u16 adc_start : 1;
         u16 reserved8 : 7;
         u16 adc_ena : 1;
#else
         u16 adc_ena : 1;
         u16 reserved8 : 7;
         u16 adc_start : 1;
         u16 reserved6 : 1;
         u16 ext_ref_ena : 1;
         u16 adc_input : 3;
         u16 vrefbyp_con : 1;
         u16 adc_sync_ena : 1;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 11: ADC data register

union BtyADCData {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
         u16 reserved0 : 5;
         u16 adc_data : 10;
         u16 adc_dat_val : 1;
#else
         u16 adc_dat_val : 1;
         u16 adc_data : 10;
         u16 reserved0 : 5;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 12: ID register

union BtyID {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
         u16 version : 6;
         u16 device : 6;
         u16 supplier : 4;
#else
         u16 supplier : 4;
         u16 device : 6;
         u16 version : 6;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// Register 13: Mode register

union BtyMode {
   public:
      u16   value;
      struct {
#ifdef   HOST_BITFIELDS_EL
         u16 aud_test : 1;
         u16 tel_test : 1;
         u16 prod_test_mode : 4;
         u16 reserved6 : 6;
         u16 dyn_vflag_ena : 1;
         u16 aud_off_can : 1;
         u16 reserved14 : 2;
#else
         u16 reserved14 : 2;
         u16 dyn_vflag_ena : 1;
         u16 reserved6 : 6;
         u16 prod_test_mode : 4;
         u16 tel_test : 1;
         u16 aud_test : 1;
#endif
      } bits;

   public:
      void Reset (void) {
         value = 0x0000;
      }
};

// ------------------------------------------------------------------------
//
// Combine all registers
//
//

struct UCB1200Registers {
   public:
      BtyIOData iodata;
      BtyIODir iodir;
      BtyREIEn reien;
      BtyFEIEn feien;
      BtyInt intrpt;                    // used only to detect 0-1 transitions
      BtyInt r_intrpt;
      BtyInt f_intrpt;
      BtyTelCRA telcra;
      BtyTelCRB telcrb;
      BtyAudCRA audcra;
      BtyAudCRB audcrb;
      BtyTSCR tscr;
      BtyADCCR adccr;
      BtyADCData adcdata;
      BtyID id;
      BtyMode mode;

   public:
      void Reset (void) {
         iodata.Reset ();
         iodir.Reset ();
         reien.Reset ();
         feien.Reset ();
         intrpt.Reset ();
         r_intrpt.Reset ();
         f_intrpt.Reset ();
         telcra.Reset ();
         telcrb.Reset ();
         audcra.Reset ();
         audcrb.Reset ();
         tscr.Reset ();
         adccr.Reset ();
         adcdata.Reset ();
         id.Reset ();
         mode.Reset ();
      }
};

#endif
